#!/usr/bin/env python
# -*- coding: utf-8 -*-

""" Python interface to simulated bees. """

import threading
import time

import zmq

from msg import dev_msgs_pb2
from msg import base_msgs_pb2


LENGTH = 2
"""
Bee length, in centimetres. 
"""

WIDTH = 0.8
"""
Bee width, in centimetres. 
"""

WHEEL_DISTANCE = 0.4
"""
Axle width of the underlying differential-wheeled model. 
"""

# Device ID definitions (for convenience)
"""
IR range sensors 
"""

OBJECT_SIDE_RIGHT = 0 #: Sensor at 90°
"""
Right object sensor 
"""

OBJECT_RIGHT_FRONT = 1
"""
Right-front object sensor 
"""

OBJECT_FRONT = 2
"""
Front object sensor 
"""

OBJECT_LEFT_FRONT = 3
"""
Left-front object sensor 
"""

OBJECT_SIDE_LEFT = 4
"""
Left object sensor 
"""

LIGHT_SENSOR = 5
"""
Light sensor 
"""


TEMP_SENSOR = 6
"""
(Front) Temperature sensor
"""

TEMP_SENSOR_FRONT = 6
"""
Front temperature sensor
"""

TEMP_SENSOR_LEFT = 7
"""
Left temperature sensor
"""

TEMP_SENSOR_BACK = 8
"""
Back temperature sensor
"""

TEMP_SENSOR_RIGHT = 9
"""
Right temperature sensor
"""

ARRAY = 10000
"""
Special value to get all sensor values from an array of sensors.
"""

class Bee:
    """ 
    The low-level interface to Bee 'robots'. 
    This clas provides an api for programming bee behaviors.
    It creates a connection to the data source, i.e., the simulated bee.
    Waits for the bee of specified by 'name' to be spawned into the simulator.

    :param string rtc_file_name: Name of the run-time-configuration (RTC) file. This file specifies the simulation connection parameters and the name of the simulated bee object.
    :param string name: The name of the bee (if not specified in the RTC file).
    :param dict kwargs: accepts strings to override values for:
        `pub_addr` (defaults to localhost:5556)
        `sub_addr` (defautls to localhost:5555)

    """
    
    def __init__(self, rtc_file_name='', name = 'Bee', **kwargs):
        
        
        if rtc_file_name:
            # Parse the rtc file
            raise NotImplementedError("RTC file parsing for Bees is not implemented yet. Please call the constructor with the name=beename argument.")
        else:
            # parse any keywords provided, otherwise take default values
            self.__pub_addr = kwargs.get('pub_addr', 'tcp://127.0.0.1:5556')
            self.__sub_addr = kwargs.get('sub_addr', 'tcp://127.0.0.1:5555')
            #self.__pub_addr = 'tcp://127.0.0.1:5556'
            #self.__sub_addr = 'tcp://127.0.0.1:5555'
            self.__name = name
        
        self.__object_readings = dev_msgs_pb2.ObjectArray()
        self.__encoder_readings = dev_msgs_pb2.DiffDrive()
        self.__true_pose = base_msgs_pb2.PoseStamped()
        self.__light_readings = base_msgs_pb2.ColorStamped()
        self.__temp_readings = dev_msgs_pb2.TemperatureArray()
        self.__vel_setpoints = dev_msgs_pb2.DiffDrive()
        self.__color_setpoint = base_msgs_pb2.ColorStamped()
        self.__airflow_reading = dev_msgs_pb2.AirflowReading()

        # Create the data update thread
        self.__connected = False
        self.__context = zmq.Context(1)
        self.__comm_thread = threading.Thread(target=self.__update_readings)
        self.__comm_thread.daemon = True
        self.__lock =threading.Lock()
        self.__comm_thread.start()

        # Connect the publisher socket
        self.__pub = self.__context.socket(zmq.PUB)
        self.__pub.connect(self.__pub_addr)

        # Wait for the connection, check every second
        while not self.__connected:
            time.sleep(1)
        print('{0} connected!'.format(self.__name))

        # Wait one more second to get all the data
        time.sleep(0.5)

    def __update_readings(self):
        """ 
        Get a message from Bee and update data. 
        """
        self.__sub = self.__context.socket(zmq.SUB)
        self.__sub.connect(self.__sub_addr)
        #self.__sub.setsockopt(zmq.HWM, 1)
        self.__sub.setsockopt(zmq.SUBSCRIBE, self.__name)
                    
        while True:
            [name, dev, cmd, data] = self.__sub.recv_multipart()
            self.__connected = True
            
            ### Range readings ###
            if dev == 'Object':
                if cmd == 'Ranges':
                    # Protect write with a lock
                    # to make sure all data is written before access
                    with self.__lock:
                        self.__object_readings.ParseFromString(data)
                else:
                    print('Unknown command {0} for {1}'.format(cmd, self.__name))

            ### Base data ###
            elif dev == 'Base':
                if cmd == 'Enc':
                    with self.__lock:
                        self.__encoder_readings.ParseFromString(data)
                elif cmd == 'GroundTruth':
                    with self.__lock:
                        self.__true_pose.ParseFromString(data)
                elif cmd == 'VelRef':
                    with self.__lock:
                        self.__vel_setpoints.ParseFromString(data)
                else:
                    print('Unknown command {0} for Bee {1}'.format(cmd, self.__name))
            ### Light sensors ###
            elif dev == 'Light':
                if cmd == 'Readings':
                    with self.__lock:
                        self.__light_readings.ParseFromString(data)
                else:
                    print('Unknown command {0} for Bee {1}'.format(cmd, self.__name))

            ### Temperature sensors ###
            elif dev == 'Temp':
                if cmd == 'Temperatures':
                    with self.__lock:
                        self.__temp_readings.ParseFromString(data)
                else:
                    print('Unknown command {0} for Bee {1}'.format(cmd, self.__name))
                    
            ### Diagnostic color actuator ###
            elif dev == 'Color':
                if cmd == 'ColorVal':
                    with self.__lock:
                        self.__color_setpoint.ParseFromString(data)
                else:
                    print('Unknown command {0} for Bee {1}'.format(cmd, self.__name))

            ### Air flow sensor ###
            elif dev == 'Airflow':
                if cmd == 'Reading':
                    with self.__lock:
                        self.__airflow_reading.ParseFromString(data)
                else:
                    print('Unknown command {0} for airflow of Bee {1}'.format(cmd, self.__name))

            else:
                print('Unknown device {0} for Bee {1}'.format(dev, self.__name))


    def get_range(self, id):
        """ 
        Returns the range reading corresponding to sensor id. 
        
        TODO: Fix the hacky correction of invalid readings
        """
        range = -1
        with self.__lock:
            if self.__object_readings.range:
                if id == ARRAY:
                    range = [val for val in self.__object_readings.range]
                else:
                    range = self.__object_readings.range[id-OBJECT_SIDE_RIGHT]

        # Hack to fix error of range 0.0 appearing
        # when no obstacles are present
        if range < 0.000001:
            range = 10

        return range

    def get_object(self, id):
        """ 
        Returns the object type detected by sensor id. 
        """
        obj = None
        with self.__lock:
            if self.__object_readings.type:
                if id == ARRAY:
                    obj = [val for val in self.__object_readings.type]
                else:
                    obj = self.__object_readings.type[id-OBJECT_SIDE_RIGHT]

        return obj

    def get_object_with_range(self, id):
        """
        Returns the (object,range) pair detected by sensor id.
        """
        r = -1
        obj = None
        with self.__lock:
            if self.__object_readings.range:
                if id == ARRAY:
                    r = [val for val in self.__object_readings.range]
                    for i in range(len(r)):
                        if r[i] < 0.000001:
                            r[i] = self.__object_readings.max_range
                    obj = [val for val in self.__object_readings.type]
                else:
                    r = self.__object_readings.range[id-OBJECT_SIDE_RIGHT]
                    # Hack to fix range 0.0 when no obstacle is present
                    if r < 0.000001:
                        r = self.__object_readings.max_range
                    obj = self.__object_readings.type[id-OBJECT_SIDE_RIGHT]

        return (obj,r)

    def get_temp(self, id = TEMP_SENSOR):
        """
        Returns the temperature reading of sensor id.
        """
        obj = None
        with self.__lock:
            if id == ARRAY:
                obj = [val for val in self.__temp_readings.temp]
            else:
                obj = self.__temp_readings.temp[id - TEMP_SENSOR]

        return obj
        
    def get_vibration_frequency(self, id):
        """
        Returns the vibration frequency of sensor id.
        """
        pass

    def get_vibration_amplitude(self, id):
        """
        Returns the vibration amplitude of sensor id.
        """
        pass

    def get_light_rgb(self, id = LIGHT_SENSOR):
        """
        :return: (r,g,b) tuple, representing the light intensities at
                 red, green and blue wavelengths (currently, the sensor
                 reports only blue intensity, r and g are always 0).
        """
        with self.__lock:
            return (self.__light_readings.color.red,
                    self.__light_readings.color.green,
                    self.__light_readings.color.blue)

    def get_airflow_intensity(self, id = 0):
        """
        :return: the airflow intensity sensed by airflow sensor id
        """
        with self.__lock:
            return self.__airflow_reading.intensity

    def get_airflow_direction(self, id = 0):
        """
        :return: the airflow angle sensed by airflow sensor id
        """
        with self.__lock:
            return self.__airflow_reading.direction

    def set_color(self,r=0.93,g=0.79,b=0):
        """
        Set the color of the bee. This can be useful for diagnostic and
        demonstration purposes.

        Take note of default values! E.g. in order to change the color to blue, 
        you have to call the function with all parameters explicitly set:

        b.set_color(r=0,g=0,b=1)

        To revert to "original" bee coloring, call the function without
        any parameters:

        b.set_color()

        :param float r: Red component intensity, between 0 and 1.
        :param float g: Green component intensity, between 0 and 1.
        :param float b: Blue component intensity, between 0 and 1.
        """

        # Limit values to [0,1] range
        r = sorted([0,r,1])[1]
        g = sorted([0,g,1])[1]
        b = sorted([0,b,1])[1]

        color = base_msgs_pb2.ColorStamped()
        color.color.red = r
        color.color.green = g
        color.color.blue = b

        self.__pub.send_multipart([self.__name,"Color","Set",color.SerializeToString()])
        

    def get_true_pose(self):
        """ 
        :return: (x,y,yaw) tuple, representing te true pose of the bee
                 in the world.
        """
        with self.__lock:
            return (self.__true_pose.pose.position.x,
                    self.__true_pose.pose.position.y,
                    self.__true_pose.pose.orientation.z)
    
    def set_vel(self, vel_left, vel_right):
        """ 
        Set wheel velocities. 

        Bee body velocities depend on wheel velocities in the following way:
        
        .. math:: v = \\frac{v_{left}+v_{right}}{2}
        .. math:: \\omega = \\frac{v_{right}-v_{left}}{d}

        where d is the distance between the wheels ("axle length").

        :param float vel_left: Left wheel velocity.
        :param float vel_right: Right wheel velocity.
        """
        vel = dev_msgs_pb2.DiffDrive();
        vel.vel_left = vel_left
        vel.vel_right = vel_right
        self.__pub.send_multipart([self.__name, "Base", "Vel", 
                                   vel.SerializeToString()])


    def get_vel_ref(self):
        """
        :return: (vel_left,vel_right) tuple of wheel velocity setpoints.
        """
        return(self.__vel_setpoints.vel_left, 
               self.__vel_setpoints.vel_right)

    def get_color(self):
        """
        :return: (r,g,b) tuple of bee color setpoints.
        """
        return(self.__color_setpoint.color.red,
               self.__color_setpoint.color.green,
               self.__color_setpoint.color.blue)


if __name__ == '__main__':
    
    bee1 = Bee(name = 'Bee')
    bee1.set_vel(5, 5)
    while True:
        for i in range(8):
            print('{0} '.format(bee1.get_range(i)))




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import yaml
import pygraphviz as pgv
from fabric.api import run, put, settings

import argparse
import os
import shutil


""" Tools for automatically deploying CASU controllers. """

class Deploy:
    """
    Class for performing deployment tasks.
    """

    def __init__(self, project_file_name):
        """
        Parses the configuration files and initializes internal data structures.
        """
        self.proj_name = os.path.splitext(os.path.basename(project_file_name))[0]
        self.fabfile_name = self.proj_name + '.py'
        #self.fabfile_name = project_file_name[:-7] + '.py'
        self.arena = {}
        self.nbg = None
        self.dep = {}

        self.project_root = os.path.dirname(os.path.abspath(project_file_name))
        self.sandbox_dir = self.proj_name + '_sandbox'

        self.prepared = False

        with open(project_file_name) as project_file:
            project = yaml.safe_load(project_file)

        # Read the .arena file
        with open(os.path.join(self.project_root, project['arena'])) as arena_file:
            self.arena = yaml.safe_load(arena_file)

        # Read the neighborhood graph, so long as one is defined.
        nbg_fname = project.get('nbg', None)
        if nbg_fname is not None and nbg_fname.lower() not in ['none', 'null']:
            # if one was missed but not explicitly so, should emit warning?
            self.nbg = pgv.AGraph(os.path.join(self.project_root, nbg_fname))


        # Read the deployment file
        with open(os.path.join(self.project_root, project['dep'])) as dep_file:
            self.dep = yaml.safe_load(dep_file)

    def prepare(self):
        """
        Prepare deployment in local folder.
        """

        cwd = os.getcwd()
        print('Changing directory to {0}'.format(self.project_root))
        os.chdir(self.project_root)
        print('Preparing files for deployment!')

        # Remove old fabfile, if it exists
        _msg = "written"
        if os.path.exists(self.fabfile_name):
            _msg = "overwritten!"
        print('The file {0} will be {1}'.format(self.fabfile_name, _msg))
        try:
            os.remove(self.fabfile_name)
        except OSError:
            # The fabfile does not exist,
            # no bigie
            pass

        # Collect fabric tasks
        fabfile_tasks = '''
from fabric.api import cd, run, settings, parallel
'''
        fabfile_all = '''
def all():
'''

        # Clean up and create new sandbox folder
        sandbox_path = os.path.join(self.project_root, self.sandbox_dir)
        _msg = "created"
        if os.path.exists(sandbox_path):
            _msg = "overwritten"
        print('The folder {0} will be {1}'.format(sandbox_path, _msg))
        try:
            shutil.rmtree(sandbox_path)
        except OSError:
            # The sandbox directory does not exist,
            # no biggie
            pass

        # Create one folder per arena layer
        # with subfolders for each casu
        os.mkdir(self.sandbox_dir)
        os.chdir(self.sandbox_dir)
        for layer in self.arena:
            os.mkdir(layer)
            os.chdir(layer)
            for casu in self.arena[layer]:
                os.mkdir(casu)
                os.chdir(casu)
                # Create the .rtc file
                with open(casu+'.rtc','a') as rtc_file:
                    yaml.dump({'name':casu}, rtc_file, default_flow_style=False)
                    yaml.dump({'pub_addr': self.arena[layer][casu]['pub_addr']},
                               rtc_file, default_flow_style=False)
                    yaml.dump({'sub_addr': self.arena[layer][casu]['sub_addr']},
                              rtc_file, default_flow_style=False)
                    yaml.dump({'msg_addr': 'tcp://*:' + self.arena[layer][casu]['msg_addr'].split(':')[-1]},
                              rtc_file, default_flow_style=False)
                    neighbors = {'neighbors':{}}
                    if self.nbg is not None:
                        sg = self.nbg.get_subgraph(layer)
                        if sg is None:
                            # no connectivity info for this layer - issue warning?
                            pass
                        elif sg.has_node(casu) is False:
                            # no info for this casu -- issue warning?
                            pass
                        else:
                            for nb in sg.out_neighbors(casu):
                                side = str(self.nbg.get_edge(casu,nb).attr['label'])
                                nb_full_name = str(nb).split('/')
                                nb_name = nb_full_name[-1]
                                nb_layer = layer
                                if len(nb_full_name) > 1:
                                    nb_layer = nb_full_name[0]
                                neighbors['neighbors'][side] = {'name': nb_name,
                                                                'address': self.arena[nb_layer][nb_name]['msg_addr']}

                    yaml.dump(neighbors, rtc_file, default_flow_style=False)

                # Copy the controller
                shutil.copy(os.path.join(self.project_root,self.dep[layer][casu]['controller']),'.')
                # Copy additional files
                extra = self.dep[layer][casu].get('extra',None)
                if extra:
                    for item in extra:
                        shutil.copy(os.path.join(self.project_root,item),'.')

                # compile extra args string
                _extra_args = self.dep[layer][casu].get('args', [])
                extra_args = " ".join(_extra_args)

                # Append to fabfile
                fabfile_tasks += '''
@parallel
def {task}():
    with settings(host_string='{host}', user='{username}'):
        with cd('{code_dir}'):
                run('./{command} {rtc} {extra_args}')
                                  '''.format(task=(layer+'_'+casu).replace('-','_'),
                                             host=self.dep[layer][casu]['hostname'],
                                             username=self.dep[layer][casu]['user'],
                                             code_dir=os.path.join(self.dep[layer][casu]['prefix'],layer,casu),
                                             command=os.path.basename(self.dep[layer][casu]['controller']),
                                             rtc=casu+'.rtc',
                                             extra_args=extra_args,
                                             )
                fabfile_all += '    {task}()\n'.format(task=(layer+'_'+casu).replace('-','_'))
                os.chdir('..')
            os.chdir(sandbox_path)

        os.chdir(self.project_root)

        # Finalize the fabric file
        with open(self.fabfile_name,'w') as fabfile:
            fabfile.write(fabfile_tasks)
            fabfile.write(fabfile_all)

        print('Preparation done!')
        print('Returning to original directory {0}'.format(cwd))
        os.chdir(cwd)

        self.prepared = True

    def deploy(self, layer_select='all'):
        """
        Perform deployment by copying files from the sandbox directory
        to their appropriate destinations.
        """

        if not self.prepared:
            self.prepare()

        cwd = os.getcwd()

        os.chdir(os.path.join(self.project_root, self.sandbox_dir))

        # Select particular layers
        selected_layers = self.dep.keys()
        if layer_select != 'all':
            selected_layers = [layer_select]

        for layer in selected_layers:
            print('Deploying layer {0} ...'.format(layer))
            os.chdir(layer)
            for casu in self.dep[layer]:
                os.chdir(casu)
                # Connect to the target machine and deploy the files.
                with settings(host_string = self.dep[layer][casu]['hostname'],
                              user = self.dep[layer][casu]['user']):
                    destdir = os.path.join(self.dep[layer][casu]['prefix'], layer, casu)
                    run('mkdir -p ' + destdir)
                    run('rm -rf ' + os.path.join(destdir,'*'))
                    put('*', destdir)
                    # Give executable permissions to the controller
                    ctrl_name = os.path.basename(self.dep[layer][casu]['controller'])
                    run('chmod +x ' + os.path.join(destdir, ctrl_name))
                os.chdir('..')
            os.chdir('..')

        os.chdir(cwd)

def main():
    parser = argparse.ArgumentParser(description='Transfer controller code to CASUs (physical or simulated)')
    parser.add_argument('project', help='name of .assisi file specifying the project details.')
    # TODO: This is fully implemented yet!
    parser.add_argument('--layer', help='Name of single layer to deploy', default='all')
    args = parser.parse_args()

    project = Deploy(args.project)
    project.deploy(args.layer)

if __name__ == '__main__':
    main()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dev_msgs.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import base_msgs_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dev_msgs.proto',
  package='AssisiMsg',
  serialized_pb='\n\x0e\x64\x65v_msgs.proto\x12\tAssisiMsg\x1a\x0f\x62\x61se_msgs.proto\"\xe8\x01\n\nRangeArray\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32 .AssisiMsg.RangeArray.SensorType:\x02IR\x12\x1d\n\rfield_of_view\x18\x03 \x01(\x02:\x06\x30.5236\x12\x14\n\tmin_range\x18\x04 \x01(\x02:\x01\x30\x12\x16\n\tmax_range\x18\x05 \x01(\x02:\x03inf\x12\r\n\x05range\x18\x06 \x03(\x02\x12\x11\n\traw_value\x18\x07 \x03(\x02\"\x14\n\nSensorType\x12\x06\n\x02IR\x10\x00\">\n\x0bTemperature\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x0c\n\x04temp\x18\x02 \x02(\x02\"C\n\x10TemperatureArray\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x0c\n\x04temp\x18\x02 \x03(\x02\"d\n\x17TemperatureWithGradient\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x0c\n\x04temp\x18\x02 \x02(\x02\x12\x0b\n\x03\x64tx\x18\x03 \x02(\x02\x12\x0b\n\x03\x64ty\x18\x04 \x02(\x02\"W\n\x11VibrationSetpoint\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x0c\n\x04\x66req\x18\x02 \x02(\x01\x12\x11\n\tamplitude\x18\x03 \x01(\x01\"o\n\x10VibrationReading\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x0c\n\x04\x66req\x18\x02 \x03(\x02\x12\x11\n\tamplitude\x18\x03 \x03(\x02\x12\x17\n\x0f\x61mplitude_stdev\x18\x04 \x03(\x02\"h\n\x15VibrationReadingArray\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12,\n\x07reading\x18\x02 \x03(\x0b\x32\x1b.AssisiMsg.VibrationReading\"S\n\tDiffDrive\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x10\n\x08vel_left\x18\x02 \x02(\x01\x12\x11\n\tvel_right\x18\x03 \x02(\x01\"\x9a\x01\n\x0bObjectArray\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1d\n\rfield_of_view\x18\x03 \x01(\x02:\x06\x30.5236\x12\x14\n\tmin_range\x18\x04 \x01(\x02:\x01\x30\x12\x16\n\tmax_range\x18\x05 \x01(\x02:\x03inf\x12\r\n\x05range\x18\x06 \x03(\x02\x12\x0c\n\x04type\x18\x07 \x03(\t\"?\n\x07\x41irflow\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x11\n\tintensity\x18\x02 \x02(\x02\"Y\n\x0e\x41irflowReading\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x11\n\tintensity\x18\x02 \x02(\x02\x12\x11\n\tdirection\x18\x03 \x02(\x02')



_RANGEARRAY_SENSORTYPE = _descriptor.EnumDescriptor(
  name='SensorType',
  full_name='AssisiMsg.RangeArray.SensorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IR', index=0, number=0,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=259,
  serialized_end=279,
)


_RANGEARRAY = _descriptor.Descriptor(
  name='RangeArray',
  full_name='AssisiMsg.RangeArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.RangeArray.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='AssisiMsg.RangeArray.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='field_of_view', full_name='AssisiMsg.RangeArray.field_of_view', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=0.5236,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_range', full_name='AssisiMsg.RangeArray.min_range', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_range', full_name='AssisiMsg.RangeArray.max_range', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=1e10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range', full_name='AssisiMsg.RangeArray.range', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_value', full_name='AssisiMsg.RangeArray.raw_value', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RANGEARRAY_SENSORTYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=47,
  serialized_end=279,
)


_TEMPERATURE = _descriptor.Descriptor(
  name='Temperature',
  full_name='AssisiMsg.Temperature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.Temperature.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temp', full_name='AssisiMsg.Temperature.temp', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=281,
  serialized_end=343,
)


_TEMPERATUREARRAY = _descriptor.Descriptor(
  name='TemperatureArray',
  full_name='AssisiMsg.TemperatureArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.TemperatureArray.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temp', full_name='AssisiMsg.TemperatureArray.temp', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=345,
  serialized_end=412,
)


_TEMPERATUREWITHGRADIENT = _descriptor.Descriptor(
  name='TemperatureWithGradient',
  full_name='AssisiMsg.TemperatureWithGradient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.TemperatureWithGradient.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temp', full_name='AssisiMsg.TemperatureWithGradient.temp', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dtx', full_name='AssisiMsg.TemperatureWithGradient.dtx', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dty', full_name='AssisiMsg.TemperatureWithGradient.dty', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=414,
  serialized_end=514,
)


_VIBRATIONSETPOINT = _descriptor.Descriptor(
  name='VibrationSetpoint',
  full_name='AssisiMsg.VibrationSetpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.VibrationSetpoint.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='freq', full_name='AssisiMsg.VibrationSetpoint.freq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='AssisiMsg.VibrationSetpoint.amplitude', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=516,
  serialized_end=603,
)


_VIBRATIONREADING = _descriptor.Descriptor(
  name='VibrationReading',
  full_name='AssisiMsg.VibrationReading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.VibrationReading.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='freq', full_name='AssisiMsg.VibrationReading.freq', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='AssisiMsg.VibrationReading.amplitude', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amplitude_stdev', full_name='AssisiMsg.VibrationReading.amplitude_stdev', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=605,
  serialized_end=716,
)


_VIBRATIONREADINGARRAY = _descriptor.Descriptor(
  name='VibrationReadingArray',
  full_name='AssisiMsg.VibrationReadingArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.VibrationReadingArray.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reading', full_name='AssisiMsg.VibrationReadingArray.reading', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=718,
  serialized_end=822,
)


_DIFFDRIVE = _descriptor.Descriptor(
  name='DiffDrive',
  full_name='AssisiMsg.DiffDrive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.DiffDrive.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vel_left', full_name='AssisiMsg.DiffDrive.vel_left', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vel_right', full_name='AssisiMsg.DiffDrive.vel_right', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=824,
  serialized_end=907,
)


_OBJECTARRAY = _descriptor.Descriptor(
  name='ObjectArray',
  full_name='AssisiMsg.ObjectArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.ObjectArray.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='field_of_view', full_name='AssisiMsg.ObjectArray.field_of_view', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=0.5236,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_range', full_name='AssisiMsg.ObjectArray.min_range', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_range', full_name='AssisiMsg.ObjectArray.max_range', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=1e10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range', full_name='AssisiMsg.ObjectArray.range', index=4,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='AssisiMsg.ObjectArray.type', index=5,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=910,
  serialized_end=1064,
)


_AIRFLOW = _descriptor.Descriptor(
  name='Airflow',
  full_name='AssisiMsg.Airflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.Airflow.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intensity', full_name='AssisiMsg.Airflow.intensity', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1066,
  serialized_end=1129,
)


_AIRFLOWREADING = _descriptor.Descriptor(
  name='AirflowReading',
  full_name='AssisiMsg.AirflowReading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.AirflowReading.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intensity', full_name='AssisiMsg.AirflowReading.intensity', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direction', full_name='AssisiMsg.AirflowReading.direction', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1131,
  serialized_end=1220,
)

_RANGEARRAY.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_RANGEARRAY.fields_by_name['type'].enum_type = _RANGEARRAY_SENSORTYPE
_RANGEARRAY_SENSORTYPE.containing_type = _RANGEARRAY;
_TEMPERATURE.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_TEMPERATUREARRAY.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_TEMPERATUREWITHGRADIENT.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_VIBRATIONSETPOINT.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_VIBRATIONREADING.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_VIBRATIONREADINGARRAY.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_VIBRATIONREADINGARRAY.fields_by_name['reading'].message_type = _VIBRATIONREADING
_DIFFDRIVE.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_OBJECTARRAY.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_AIRFLOW.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
_AIRFLOWREADING.fields_by_name['header'].message_type = base_msgs_pb2._HEADER
DESCRIPTOR.message_types_by_name['RangeArray'] = _RANGEARRAY
DESCRIPTOR.message_types_by_name['Temperature'] = _TEMPERATURE
DESCRIPTOR.message_types_by_name['TemperatureArray'] = _TEMPERATUREARRAY
DESCRIPTOR.message_types_by_name['TemperatureWithGradient'] = _TEMPERATUREWITHGRADIENT
DESCRIPTOR.message_types_by_name['VibrationSetpoint'] = _VIBRATIONSETPOINT
DESCRIPTOR.message_types_by_name['VibrationReading'] = _VIBRATIONREADING
DESCRIPTOR.message_types_by_name['VibrationReadingArray'] = _VIBRATIONREADINGARRAY
DESCRIPTOR.message_types_by_name['DiffDrive'] = _DIFFDRIVE
DESCRIPTOR.message_types_by_name['ObjectArray'] = _OBJECTARRAY
DESCRIPTOR.message_types_by_name['Airflow'] = _AIRFLOW
DESCRIPTOR.message_types_by_name['AirflowReading'] = _AIRFLOWREADING

class RangeArray(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RANGEARRAY

  # @@protoc_insertion_point(class_scope:AssisiMsg.RangeArray)

class Temperature(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TEMPERATURE

  # @@protoc_insertion_point(class_scope:AssisiMsg.Temperature)

class TemperatureArray(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TEMPERATUREARRAY

  # @@protoc_insertion_point(class_scope:AssisiMsg.TemperatureArray)

class TemperatureWithGradient(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TEMPERATUREWITHGRADIENT

  # @@protoc_insertion_point(class_scope:AssisiMsg.TemperatureWithGradient)

class VibrationSetpoint(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VIBRATIONSETPOINT

  # @@protoc_insertion_point(class_scope:AssisiMsg.VibrationSetpoint)

class VibrationReading(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VIBRATIONREADING

  # @@protoc_insertion_point(class_scope:AssisiMsg.VibrationReading)

class VibrationReadingArray(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VIBRATIONREADINGARRAY

  # @@protoc_insertion_point(class_scope:AssisiMsg.VibrationReadingArray)

class DiffDrive(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DIFFDRIVE

  # @@protoc_insertion_point(class_scope:AssisiMsg.DiffDrive)

class ObjectArray(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OBJECTARRAY

  # @@protoc_insertion_point(class_scope:AssisiMsg.ObjectArray)

class Airflow(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AIRFLOW

  # @@protoc_insertion_point(class_scope:AssisiMsg.Airflow)

class AirflowReading(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AIRFLOWREADING

  # @@protoc_insertion_point(class_scope:AssisiMsg.AirflowReading)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base_msgs.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='base_msgs.proto',
  package='AssisiMsg',
  serialized_pb='\n\x0f\x62\x61se_msgs.proto\x12\tAssisiMsg\"!\n\x04Time\x12\x0b\n\x03sec\x18\x01 \x02(\x04\x12\x0c\n\x04nsec\x18\x02 \x02(\x04\"F\n\x06Header\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1e\n\x05stamp\x18\x02 \x01(\x0b\x32\x0f.AssisiMsg.Time\x12\x10\n\x08\x66rame_id\x18\x03 \x01(\t\"+\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\"-\n\x07Vector3\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x0c\n\x01z\x18\x03 \x02(\x01:\x01\x30\"A\n\nQuaternion\x12\x0c\n\x01x\x18\x01 \x01(\x01:\x01\x30\x12\x0c\n\x01y\x18\x02 \x01(\x01:\x01\x30\x12\t\n\x01z\x18\x03 \x02(\x01\x12\x0c\n\x01w\x18\x04 \x01(\x01:\x01\x31\"V\n\x04Pose\x12\"\n\x08position\x18\x01 \x02(\x0b\x32\x10.AssisiMsg.Point\x12*\n\x0borientation\x18\x02 \x02(\x0b\x32\x15.AssisiMsg.Quaternion\"O\n\x0bPoseStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1d\n\x04pose\x18\x02 \x02(\x0b\x32\x0f.AssisiMsg.Pose\"P\n\x05Twist\x12\"\n\x06linear\x18\x01 \x02(\x0b\x32\x12.AssisiMsg.Vector3\x12#\n\x07\x61ngular\x18\x02 \x02(\x0b\x32\x12.AssisiMsg.Vector3\"R\n\x0cTwistStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1f\n\x05twist\x18\x02 \x02(\x0b\x32\x10.AssisiMsg.Twist\"@\n\x05\x43olor\x12\x0b\n\x03red\x18\x01 \x02(\x01\x12\r\n\x05green\x18\x02 \x02(\x01\x12\x0c\n\x04\x62lue\x18\x03 \x02(\x01\x12\r\n\x05\x61lpha\x18\x04 \x01(\x01\"R\n\x0c\x43olorStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1f\n\x05\x63olor\x18\x02 \x02(\x0b\x32\x10.AssisiMsg.Color\"R\n\x07Polygon\x12\"\n\x08vertices\x18\x01 \x03(\x0b\x32\x10.AssisiMsg.Point\x12\x11\n\x06height\x18\x02 \x01(\x01:\x01\x31\x12\x10\n\x04mass\x18\x03 \x01(\x01:\x02-1\"X\n\x0ePolygonStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12#\n\x07polygon\x18\x02 \x02(\x0b\x32\x12.AssisiMsg.Polygon\">\n\x08\x43ylinder\x12\x0e\n\x06radius\x18\x01 \x02(\x01\x12\x11\n\x06height\x18\x02 \x01(\x01:\x01\x31\x12\x0f\n\x04mass\x18\x03 \x01(\x01:\x01\x31\"[\n\x0f\x43ylinderStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12%\n\x08\x63ylinder\x18\x02 \x02(\x0b\x32\x13.AssisiMsg.Cylinder')




_TIME = _descriptor.Descriptor(
  name='Time',
  full_name='AssisiMsg.Time',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='AssisiMsg.Time.sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nsec', full_name='AssisiMsg.Time.nsec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=30,
  serialized_end=63,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='AssisiMsg.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='AssisiMsg.Header.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='AssisiMsg.Header.stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='AssisiMsg.Header.frame_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=65,
  serialized_end=135,
)


_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='AssisiMsg.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='AssisiMsg.Point.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='AssisiMsg.Point.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='AssisiMsg.Point.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=137,
  serialized_end=180,
)


_VECTOR3 = _descriptor.Descriptor(
  name='Vector3',
  full_name='AssisiMsg.Vector3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='AssisiMsg.Vector3.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='AssisiMsg.Vector3.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='AssisiMsg.Vector3.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=182,
  serialized_end=227,
)


_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='AssisiMsg.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='AssisiMsg.Quaternion.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='AssisiMsg.Quaternion.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='AssisiMsg.Quaternion.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w', full_name='AssisiMsg.Quaternion.w', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=229,
  serialized_end=294,
)


_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='AssisiMsg.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='AssisiMsg.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='AssisiMsg.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=296,
  serialized_end=382,
)


_POSESTAMPED = _descriptor.Descriptor(
  name='PoseStamped',
  full_name='AssisiMsg.PoseStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.PoseStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='AssisiMsg.PoseStamped.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=384,
  serialized_end=463,
)


_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='AssisiMsg.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='AssisiMsg.Twist.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='AssisiMsg.Twist.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=465,
  serialized_end=545,
)


_TWISTSTAMPED = _descriptor.Descriptor(
  name='TwistStamped',
  full_name='AssisiMsg.TwistStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.TwistStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='twist', full_name='AssisiMsg.TwistStamped.twist', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=547,
  serialized_end=629,
)


_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='AssisiMsg.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='red', full_name='AssisiMsg.Color.red', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='green', full_name='AssisiMsg.Color.green', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blue', full_name='AssisiMsg.Color.blue', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='AssisiMsg.Color.alpha', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=631,
  serialized_end=695,
)


_COLORSTAMPED = _descriptor.Descriptor(
  name='ColorStamped',
  full_name='AssisiMsg.ColorStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.ColorStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='AssisiMsg.ColorStamped.color', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=697,
  serialized_end=779,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='AssisiMsg.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='AssisiMsg.Polygon.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='AssisiMsg.Polygon.height', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass', full_name='AssisiMsg.Polygon.mass', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=781,
  serialized_end=863,
)


_POLYGONSTAMPED = _descriptor.Descriptor(
  name='PolygonStamped',
  full_name='AssisiMsg.PolygonStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.PolygonStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='AssisiMsg.PolygonStamped.polygon', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=865,
  serialized_end=953,
)


_CYLINDER = _descriptor.Descriptor(
  name='Cylinder',
  full_name='AssisiMsg.Cylinder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='radius', full_name='AssisiMsg.Cylinder.radius', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='AssisiMsg.Cylinder.height', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass', full_name='AssisiMsg.Cylinder.mass', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=955,
  serialized_end=1017,
)


_CYLINDERSTAMPED = _descriptor.Descriptor(
  name='CylinderStamped',
  full_name='AssisiMsg.CylinderStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.CylinderStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cylinder', full_name='AssisiMsg.CylinderStamped.cylinder', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1019,
  serialized_end=1110,
)

_HEADER.fields_by_name['stamp'].message_type = _TIME
_POSE.fields_by_name['position'].message_type = _POINT
_POSE.fields_by_name['orientation'].message_type = _QUATERNION
_POSESTAMPED.fields_by_name['header'].message_type = _HEADER
_POSESTAMPED.fields_by_name['pose'].message_type = _POSE
_TWIST.fields_by_name['linear'].message_type = _VECTOR3
_TWIST.fields_by_name['angular'].message_type = _VECTOR3
_TWISTSTAMPED.fields_by_name['header'].message_type = _HEADER
_TWISTSTAMPED.fields_by_name['twist'].message_type = _TWIST
_COLORSTAMPED.fields_by_name['header'].message_type = _HEADER
_COLORSTAMPED.fields_by_name['color'].message_type = _COLOR
_POLYGON.fields_by_name['vertices'].message_type = _POINT
_POLYGONSTAMPED.fields_by_name['header'].message_type = _HEADER
_POLYGONSTAMPED.fields_by_name['polygon'].message_type = _POLYGON
_CYLINDERSTAMPED.fields_by_name['header'].message_type = _HEADER
_CYLINDERSTAMPED.fields_by_name['cylinder'].message_type = _CYLINDER
DESCRIPTOR.message_types_by_name['Time'] = _TIME
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['Vector3'] = _VECTOR3
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
DESCRIPTOR.message_types_by_name['PoseStamped'] = _POSESTAMPED
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST
DESCRIPTOR.message_types_by_name['TwistStamped'] = _TWISTSTAMPED
DESCRIPTOR.message_types_by_name['Color'] = _COLOR
DESCRIPTOR.message_types_by_name['ColorStamped'] = _COLORSTAMPED
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['PolygonStamped'] = _POLYGONSTAMPED
DESCRIPTOR.message_types_by_name['Cylinder'] = _CYLINDER
DESCRIPTOR.message_types_by_name['CylinderStamped'] = _CYLINDERSTAMPED

class Time(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TIME

  # @@protoc_insertion_point(class_scope:AssisiMsg.Time)

class Header(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _HEADER

  # @@protoc_insertion_point(class_scope:AssisiMsg.Header)

class Point(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POINT

  # @@protoc_insertion_point(class_scope:AssisiMsg.Point)

class Vector3(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VECTOR3

  # @@protoc_insertion_point(class_scope:AssisiMsg.Vector3)

class Quaternion(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _QUATERNION

  # @@protoc_insertion_point(class_scope:AssisiMsg.Quaternion)

class Pose(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSE

  # @@protoc_insertion_point(class_scope:AssisiMsg.Pose)

class PoseStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSESTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.PoseStamped)

class Twist(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TWIST

  # @@protoc_insertion_point(class_scope:AssisiMsg.Twist)

class TwistStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TWISTSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.TwistStamped)

class Color(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COLOR

  # @@protoc_insertion_point(class_scope:AssisiMsg.Color)

class ColorStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COLORSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.ColorStamped)

class Polygon(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POLYGON

  # @@protoc_insertion_point(class_scope:AssisiMsg.Polygon)

class PolygonStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POLYGONSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.PolygonStamped)

class Cylinder(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDER

  # @@protoc_insertion_point(class_scope:AssisiMsg.Cylinder)

class CylinderStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDERSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.CylinderStamped)


# @@protoc_insertion_point(module_scope)



""" 
The assisipy Python package implements the API for monitoring and controlling CASU devices.
It works both with simulated CASUS and pyhsical devices. It also provides several utility
classes for interacting with the simulation engine.
"""

__version__ = '0.13.0'




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Tool for remotely running CASU controllers.
"""

# none of the fabric tools are used [directly], import removed
#from fabric.api import settings, cd, run, env

import yaml

#import os.path
import os
import argparse
import subprocess

class AssisiRun:
    """
    Remote execution tool.
    """
    def __init__(self, project_name):
        """
        Constructor.
        """

        self.proj_name = os.path.splitext(os.path.basename(project_name))[0]
        self.project_root = os.path.dirname(os.path.abspath(project_name))
        self.fabfile_name = self.proj_name + '.py'
        self.depspec = {}
        with open(project_name) as project:
            project_spec = yaml.safe_load(project)
            with open(os.path.join(self.project_root, project_spec['dep'])) as depfile:
                self.depspec = yaml.safe_load(depfile)

        # Running controllers
        self.running = {}

    def run(self):
        """
        Execute the controllers.
        """
        #env.parallel = True
        cwd = os.getcwd()
        print('Changing directory to {0}'.format(self.project_root))
        os.chdir(self.project_root)
        print('Preparing files for deployment!')
        counter = 0
        for layer in self.depspec:
            for casu in self.depspec[layer]:
                taskname = layer.replace('-','_') + '_' + casu.replace('-','_')
                cmd = 'fab -f {0} {1}'.format(self.fabfile_name, taskname)
                print(cmd)
                self.running[taskname] = subprocess.Popen(cmd,shell='True')

        for taskname in self.running:
            self.running[taskname].wait()

        # back to original directory.
        os.chdir(cwd)

def main():
    parser = argparse.ArgumentParser(description='Run a set of CASU controllers.')
    parser.add_argument('project', help='name of .assisi file specifying the project details.')
    args = parser.parse_args()

    project = AssisiRun(args.project)
    project.run()

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Tool for collecting data logged by CASUs after an experiment.
"""

import yaml
from fabric.api import get, run, settings

import argparse
import os, errno

def mkdir_p(path):
    '''
    recursively create paths, and do not raise error if already exists

    source: http://stackoverflow.com/a/600612
    '''
    try:
        os.makedirs(path)
    except OSError as exc:  # Python >2.5
        if exc.errno == errno.EEXIST and os.path.isdir(path):
            pass
        else:
            raise

class DataCollector:
    """
    Class for automatically retrieving CASU logs.
    """

    def __init__(self, project_file_name, clean=False, logpath=None):
        """
        Parses the configuration file and initializes internal data structures.
        """

        self.clean = clean

        self.arena = {}
        self.dep = {}

        self.project_root = os.path.dirname(os.path.abspath(project_file_name))
        self.proj_name = os.path.splitext(os.path.basename(project_file_name))[0]

        if logpath is None or logpath == 'None':
            self.custom_logpath = False
            self.data_dir = 'data_' + self.proj_name
        else:
            self.custom_logpath = True
            self.data_dir = os.path.join(
                os.path.abspath(logpath),
                'data_' + self.proj_name)


        self.collected = False

        with open(project_file_name) as project_file:
            project = yaml.safe_load(project_file)

        # Read the .arena file
        with open(os.path.join(self.project_root, project['arena'])) as arena_file:
            self.arena = yaml.safe_load(arena_file)

        # Read the deployment file
        with open(os.path.join(self.project_root, project['dep'])) as dep_file:
            self.dep = yaml.safe_load(dep_file)

    def collect(self):
        """
        Collect the data to the local machine.
        """

        # Create data folder on local machine
        cwd = os.getcwd()
        if cwd != self.project_root and not self.custom_logpath:
        ##if cwd != self.project_root :
            print('Changing directory to {0}'.format(self.project_root))
            os.chdir(self.project_root)


        try:
            # attempt to create data directory (func is recursive if necessary)
            mkdir_p(self.data_dir)
            #os.mkdir(self.data_dir)
            print('Created folder {0}.'.format(self.data_dir))
        except OSError:
            # The data directory already exists
            # that's ok
            pass

        os.chdir(self.data_dir)

        # Download the data from deployment targets
        for layer in self.dep:
            try:
                os.mkdir(layer)
                print('Created folder {0}.'.format(layer))
            except OSError:
                # The directory already exists
                pass
            os.chdir(layer)
            for casu in self.dep[layer]:
                try:
                    os.mkdir(casu)
                    print('Created folder {0}.'.format(casu))
                except OSError:
                    # The directory already exists
                    pass
                os.chdir(casu)
                with settings(host_string = self.dep[layer][casu]['hostname'],
                              user = self.dep[layer][casu]['user'],
                              warn_only = True):
                    patterns = (['*.csv',] +
                            self.dep[layer][casu].get('results', []) )

                    for pattern in patterns:
                        targetfiles = os.path.join(self.dep[layer][casu]['prefix'],
                                layer, casu, pattern)
                        get(targetfiles,'.')
                        if self.clean:
                            run('rm ' + targetfiles)

                os.chdir('..')

            os.chdir('..')

        # Return to the original directory
        os.chdir(cwd)


def main():
    parser = argparse.ArgumentParser(description='Collect CASU logs. Currently assumes that the logs are located in the same folder as the controller.')
    parser.add_argument('project', help='Project file name (.assisi).')
    parser.add_argument('--logpath', default=None, help="override for path where logs will be written to")
    parser.add_argument('--clean', action='store_true', default=False,
                        help='Remove original log files after copying.')
    args = parser.parse_args()
    dc = DataCollector(args.project, args.clean, args.logpath)
    dc.collect()

if __name__ == '__main__':
    main()



'''
A setuptools script that follows recommendations (where relevant) from:
  https://github.com/pypa/sampleproject/blob/master/setup.py
  https://github.com/jeffknupp/sandman/blob/develop/setup.py
  http://pythonhosted.org/setuptools/setuptools.html


Note: to ensure that the description file is available in the target,
(needed when setup.py is executed, either manually or by easy_install/pip)
the MANIFEST.in file is used.
package_data and data_files are ignored by setuptools when compiling
source distributions!

Note: for the entry points to work, the rhs expects the target to be a
function in a module, that takes no arguments:
http://stackoverflow.com/q/2853088
Luckily, argparse somehow access sys.argv from wherever they are created
so arguments need to be passed to that entry point func.
The four tools used in deployment scenarios have these entry points set up.

'''


from setuptools import setup, find_packages
import codecs
import os
import re

here = os.path.abspath(os.path.dirname(__file__))

def read(*parts):
    # source: https://github.com/jeffknupp/sandman/blob/develop/setup.py
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()

def find_version(*file_paths):
    # source: https://github.com/jeffknupp/sandman/blob/develop/setup.py
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

long_description = read('DESCRIPTION.rst')

# setting up entry points to code within the python package - hopefully..
console_scripts = [
            ['sim.py = assisipy.sim:main'],
            ['assisirun.py = assisipy.assisirun:main'],
            ['deploy.py = assisipy.deploy:main'],
            ['collect_data.py = assisipy.collect_data:main'],
]



setup(
    name="assisipy",
    version=find_version('assisipy', '__init__.py'),
    packages=find_packages(exclude=["doc"]),

    description="Python API for the ASSISbf project",
    long_description=long_description,

    # The project URL.
    url='https://github.com/larics/assisi-python',

    # Author details
    author='LARICS Laboratory',
    author_email='larics@fer.hr',

    license='LGPL',

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Scientific/Engineering :: Artificial Life',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Programming Language :: Python :: 2.7'
    ],

    keywords='assisi, assisibf, collective systems',

    # Run-time dependencies (will be installed by pip)
    install_requires = ['pyzmq','protobuf','pyyaml', 'pygraphviz', 'Fabric'],

    entry_points     = {
        'console_scripts': console_scripts,
    }

)
